@@ -3,10 +3,10 @@ use {
     crate::{
         app::*,
         errors::ConfError,
-        keys,
+        keys::KEY_FORMAT,
         path::{self, PathAnchor},
     },
-    crossterm::event::{KeyCode, KeyEvent, KeyModifiers},
+    crossterm::event::KeyEvent,
     std::path::PathBuf,
 };
 
@@ -48,6 +48,9 @@ pub struct Verb {
     /// the type of selection this verb applies to
     pub selection_condition: SelectionType,
 
+    /// extension filtering. If empty, all extensions apply
+    pub file_extensions: Vec<String>,
+
     /// whether the verb needs a selection
     pub needs_selection: bool,
 
@@ -101,6 +104,7 @@ impl Verb {
             execution,
             description,
             selection_condition: SelectionType::Any,
+            file_extensions: Vec::new(),
             needs_selection,
             needs_another_panel,
             auto_exec: true,
@@ -111,7 +115,7 @@ impl Verb {
         self.keys_desc = self
             .keys
             .iter()
-            .map(|&k| keys::key_event_desc(k))
+            .map(|&k| KEY_FORMAT.to_string(k))
             .collect::<Vec<String>>() // no way to join an iterator today ?
             .join(", ");
     }
@@ -126,24 +130,6 @@ impl Verb {
         }
         self.update_key_desc();
     }
-    pub fn with_alt_key(self, chr: char) -> Self {
-        self.with_key(KeyEvent {
-            code: KeyCode::Char(chr),
-            modifiers: KeyModifiers::ALT,
-        })
-    }
-    pub fn with_control_key(self, chr: char) -> Self {
-        self.with_key(KeyEvent {
-            code: KeyCode::Char(chr),
-            modifiers: KeyModifiers::CONTROL,
-        })
-    }
-    pub fn with_char_key(self, chr: char) -> Self {
-        self.with_key(KeyEvent {
-            code: KeyCode::Char(chr),
-            modifiers: KeyModifiers::NONE,
-        })
-    }
     pub fn no_doc(mut self) -> Self {
         self.show_in_doc = false;
         self
@@ -236,7 +222,7 @@ impl Verb {
         if let VerbExecution::Internal(internal_exec) = &self.execution {
             if internal_exec.internal == Internal::focus {
                 if let Some(sel) = sel_info.one_sel() {
-                    let arg = invocation.args.as_ref().or_else(|| internal_exec.arg.as_ref());
+                    let arg = invocation.args.as_ref().or(internal_exec.arg.as_ref());
                     let pb;
                     let arg_path = if let Some(arg) = arg {
                         pb = path::path_from(sel.path, PathAnchor::Unspecified, arg);
